@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Xorg
 #
-# This software is Copyright (c) 2011 by Dominique Dumont.
+# This software is Copyright (c) 2015 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,10 +9,7 @@
 #
 
 package Config::Model::Backend::Xorg::Write ;
-{
-  $Config::Model::Backend::Xorg::Write::VERSION = '1.106';
-}
-
+$Config::Model::Backend::Xorg::Write::VERSION = '1.107';
 use Any::Moose 'Role' ;
 
 use Carp ;
@@ -343,7 +340,6 @@ sub write_all {
        leaf_cb => \&wr_leaf ,
        node_element_cb => \&wr_node ,
        check_list_element_cb => \&wr_check_list ,
-       experience => 'master' ,
        fallback => 'all',
       ) ;
 
